<?php
$default_options_info = array(
	'adauthint_server_opts'	=> array(
		'domain_controllers'	=> array(
			'opt_type'		=> 'string',
			'opt_default'	=> NULL,
			'opt_val'		=> $this->domain_controllers,
			'opt_label'		=> 'Domain controllers',
			'opt_note'		=> 'Separate with semicolons, e.g. "dc1.domain.tld;dc2.domain.tld"',
		),
			'port'				=> array(
			'opt_type'		=> 'int',
			'opt_default'	=> 389,
			'opt_val'		=> $this->port,
			'opt_label'		=> 'Port on which the AD listens',
			'opt_note'		=> 'Defaults to 389',
		),
		'secure_connection'		=> array(
			'opt_type'		=> 'bool',
			'opt_default'	=> false,
			'opt_val'		=> $this->secure_connection,
			'opt_label'		=> 'Use secure connection?',
			'opt_note'		=> 'Secure the connection between the WordPress and the Active Directory Servers using TLS. Note: To use TLS, you must set the LDAP Port to 389.',
		),
		'bind_user' 			=> array(
			'opt_type'		=> 'string',
			'opt_default'	=> NULL,
			'opt_val'		=> $this->bind_user,
			'opt_label'		=> 'Bind user',
			'opt_note'		=> 'Username for non-anonymous requests to AD (e.g. "ldapuser@domain.tld"). Leave empty for anonymous requests.',
		),
		'bind_user_password'	=> array(
			'opt_type'		=> 'password',
			'opt_default'	=> NULL,
			'opt_val'		=> $this->bind_user_password,
			'opt_label'		=> 'Bind user password',
		),
		'base_dn' 				=> array(
			'opt_type'		=> 'string',
			'opt_default'	=> NULL,
			'opt_val'		=> $this->base_dn,
			'opt_label'		=> 'Base DN',
			'opt_note'		=> 'e.g., "ou=unit,dc=domain,dc=tld"',
		),
	),
	'adauthint_user_opts' 	=> array(
		'auto_user_create' 		=> array(
			'opt_type'		=> 'bool',
			'opt_default'	=> true,
			'opt_val'		=> $this->auto_user_create,
			'opt_label'		=> 'Automatically create new user?',
			'opt_note'		=> array(
				'Should a new user be created automatically if not already in the WordPress database?',
				'Created users will obtain the role defined under "New User Default Role" on the <a href="options-general.php">General Options</a> page.',
				'This setting is separate from the Role Equivalent Groups option, below.',
				'<b>Users with role equivalent groups will be created even if this setting is turned off</b> (because if you didn\'t want this to happen, you would leave that option blank.)',
			),
		),
		'auto_user_update'		=> array(
			'opt_type'		=> 'bool',
			'opt_default'	=> false,
			'opt_val'		=> $this->auto_user_update,
			'opt_label'		=> 'Automatic User Update',
			'opt_note'		=> array(
				'Should the users be updated in the WordPress database everytime they logon?',
				'<strong>Works only if Automatic User Creation is turned on.</strong>',
			),
		),
		'default_email_domain'	=> array(
			'opt_type'		=> 'string',
			'opt_default'	=> NULL,
			'opt_val'		=> $this->default_email_domain,
			'opt_label'		=> 'Default email domain',
			'opt_note'		=> 'If the Active Directory attribute \'mail\' is blank, a user\'s email will be set to username@whatever-this-says',
		),
		'dup_account_handling'	=> array(
			'opt_type'		=> 'select',
			'opt_default'	=> 'prevent',
			'opt_val'		=> $this->dup_account_handling,
			'opt_label'		=> 'Email Address Conflict Handling',
			'opt_note'		=> 'Choose how to handle email address conflicts.<dl><dt>Prevent:</dt><dd>User is not created, if his email address is already in use by another user. (recommended)</dd><dt>Allow:</dt><dd>Allow users to share one email address. (UNSAFE)</dd><dt>Create:</dt><dd>In case of conflict, the new user is created with a unique email address.</dd></dl>',
			'opt_choices'	=> array(
					'prevent'	=> 'Prevent (recommended)',
					'allow'		=> 'Allow (UNSAFE)',
					'create'	=> 'Create',
			),
		),
		'user_account_suffix'	=> array(
			'opt_type'		=> 'string',
			'opt_default'	=> NULL,
			'opt_val'		=> $this->user_account_suffix,
			'opt_label'		=> 'Account Suffix',
			'opt_note'		=> 'will be appended to all usernames in the Active Directory authentication process; e.g., "@domain.tld".',
		),
		'append_user_suffix'	=> array(
			'opt_type'		=> 'bool',
			'opt_default'	=> true,
			'opt_val'		=> $this->append_user_suffix,
			'opt_label'		=> 'Append account suffix to new created usernames.',
			'opt_note'		=> 'If checked, the account suffix (see above) will be appended to the usernames of new created users.',
		),
		'display_name'			=> array(
			'opt_type'		=> 'select',
			'opt_default'	=> 'samaccountname',
			'opt_val'		=> $this->display_name,
			'opt_label'		=> 'Display name',
			'opt_note'		=> 'Choose user\'s Active Directory attribute to be used as display name.',
			'opt_choices'	=> array(
				'samaccountname'	=> 'sAMAccountName (the username)',
				'displayname'		=> 'displayName',
				'description'		=> 'description',
				'givenname'			=> 'givenName (firstname)',
				'sn'				=> 'SN (lastname)',
				'cn'				=> 'CN (Common Name, the whole name)',
				'mail'				=> 'mail',
			),
		),
		'allow_local_password'	=> array(
			'opt_type'		=> 'bool',
			'opt_default'	=> false,
			'opt_val'		=> $this->append_user_suffix,
			'opt_label'		=> 'Enable local password changes',
			'opt_note'		=> array(
				'Allow users to change their local (<strong>non AD</strong>) WordPress password',
				'<strong>If activated, a password change will update the local WordPress database only. No changes in Active Directory will be made.</strong>',
			),
		),
	),
	'adauthint_auth_opts'	=> array(
		'auth_from_ad_grp'		=> array(
			'opt_type'		=> 'bool',
			'opt_default'	=> false,
			'opt_val'		=> $this->auth_from_ad_grp,
			'opt_label'		=> 'Authorize by group membership',
			'opt_note'		=> 'Users are authorized for login only when they are members of a specific AD group.',
		),
		'auth_groups'			=> array(
			'opt_type'		=> 'string',
			'opt_default'	=> NULL,
			'opt_val'		=> $this->auth_groups,
			'opt_label'		=> 'Group(s)',
			'opt_note'		=> 'Seperate multiple groups by semicolon (e.g. "domain-users;WP-Users;test-users").',
		),
		'role_equiv_groups'		=> array(
			'opt_type'		=> 'string',
			'opt_default'	=> NULL,
			'opt_val'		=> $this->role_equiv_groups,
			'opt_label'		=> 'Role Equivalent Groups',
			'opt_note'		=> array(
				'List of Active Directory groups which correspond to WordPress user roles.',
				'When a user is first created, his role will correspond to what is specified here.<br/>Format: AD-Group1=WordPress-Role1;AD-Group1=WordPress-Role1;...',
				'E.g., "Soc-Faculty=faculty" or "Faculty=faculty;Students=subscriber"',
				'A user will be created based on the first math, from left to right, so you should obviously put the more powerful groups first.',
				'<ol><li>WordPress stores roles as lower case ("Subscriber" is stored as "subscriber")</li><li>Active Directory groups are case-sensitive.</li><li>Group memberships cannot be checked across domains.  So if you have two domains, instr and qc, and qc is the domain specified above, if instr is linked to qc, I can authenticate instr users, but not check instr group memberships.</li></ol>',
			),
		),
	),
	'adauthint_security_opts'	=> array(
		'max_login_attempts'	=> array(
			'opt_type'		=> 'int',
			'opt_default'	=> 3,
			'opt_val'		=> $this->max_login_attempts,
			'opt_label'		=> 'Maximum number of allowed login attempts',
			'opt_note'		=> 'Maximum number of failed login attempts before a user account is blocked. If empty or "0" Brute Force Protection is turned off.',
		),
		'blocking_time' 		=> array(
			'opt_type'		=> 'int',
			'opt_default'	=> 30,
			'opt_val'		=> $this->blocking_time,
			'opt_label'		=> 'Lock-out Time',
			'opt_note'		=> 'How long should the account be locked out after reaching the maximum number of failed attempts (in seconds)?',
		),
		'notify_user'			=> array(
			'opt_type'		=> 'bool',
			'opt_default'	=> false,
			'opt_val'		=> $this->notify_user,
			'opt_label'		=> 'Notify user when account is locked',
		),
		'notify_admin'			=> array(
			'opt_type'		=> 'bool',
			'opt_default'	=> false,
			'opt_val'		=> $this->notify_admin,
			'opt_label'		=> 'Notify admin when user account is locked',
		),
		'admin_email'			=> array(
			'opt_type'		=> 'string',
			'opt_default'	=> NULL,
			'opt_val'		=> $this->admin_email,
			'opt_label'		=> 'Administrator e-mail address',
		),
	),
);
?>