<?php
/**
 * Handle Multi-Network actions for the ADAuthInt Plugin
 * @package wordpress
 * @subpackage ADAuthInt
 */

check_admin_referer( '_adai_options' );

if( !isset( $_GET['options-action'] ) )
	exit;

if( !defined('ADAI_IS_MULTINETWORK') || !ADAI_IS_MULTINETWORK )
	exit;

global $wpdb;

echo '
	<div class="wrap">
		<h2>' . __('AD Authentication Integration - Multi-Network Activation') . '</h2>';

if( $_GET['options-action'] == 'multi_network_activate' ) {
	if( !function_exists( 'wpmn_network_exists' ) )
		require( WP_PLUGIN_DIR . '/wp-multi-network/wp-multi-network.php' );
	if( !class_exists( 'ADAuthInt_Plugin' ) )
		require( ADAUTHINT_ABS_DIR . '/' . 'active-directory-authentication-integration.php' );
	
	$networks = $wpdb->get_results( $wpdb->prepare( 'SELECT DISTINCT id FROM ' . $wpdb->site ) );
	if( count( $networks ) ) {
		foreach( $networks as $network ) {
			$opts_updated = false;
			ADAuthInt_Plugin::switch_to_site( $network->id );
			if( current_user_can( 'delete-users' ) ) {
				$asp = maybe_unserialize( get_site_option( 'active_sitewide_plugins' ) );
				if( !array_key_exists( ADAUTHINT_PLUGIN_BASENAME, $asp ) ) {
					$asp = array_merge( $asp, array( ADAUTHINT_PLUGIN_BASENAME => time() ) );
					update_site_option( 'active_sitewide_plugins', $asp );
					if( !isset( $ADAuthInt_Plugin_Obj ) ) {
						$ADAuthInt_Plugin_Obj = new ADAuthInt_Plugin();
						$opts_updated = true;
					} else {
						$ADAuthInt_Plugin_Obj->_load_options();
						$opts_updated = true;
					}
					if( $opts_updated ) {
						echo '<p>';
						printf( __( 'The AD Authentication Integration options were successfully updated for the network with an ID of %d, as well.', ADAUTHINT_TEXT_DOMAIN ), $network->id );
						echo '</p>';
					}
					echo '<p>' . __( 'The AD Authentication Integration plug-in was successfully network-activated on the network with an ID of ', ADAUTHINT_TEXT_DOMAIN ) . $network->id . '</p>';
				} else {
					echo '<p>';
					printf( __( 'The AD Authentication Integration plug-in was already network-active on the network with an ID of %d, therefore, no changes were made.', ADAUTHINT_TEXT_DOMAIN ), $network->id );
					echo '</p>';
				}
			} else {
				echo '<p>' . __( 'You do not have the appropriate permissions to network activate this plug-in on the network with an ID of ', ADAUTHINT_TEXT_DOMAIN ) . $network->id . '</p>';
			}
			ADAuthInt_Plugin::restore_current_site();
		}
		echo '</div>';
	} else {
		echo '<p>' . __( 'Multiple networks could not be found, therefore, no additional changes were made.', ADAUTHINT_TEXT_DOMAIN ) . '</p>';
		echo '</div>';
	}
} elseif( $_GET['options-action'] == 'multi_network_deactivate' ) {
	if( !function_exists( 'wpmn_network_exists' ) )
		require( WP_PLUGIN_DIR . '/wp-multi-network/wp-multi-network.php' );
	if( !class_exists( 'ADAuthInt_Plugin' ) )
		require( ADAUTHINT_ABS_DIR . '/class-' . 'active-directory-authentication-integration.php' );
	
	$networks = $wpdb->get_results( $wpdb->prepare( 'SELECT DISTINCT id FROM ' . $wpdb->site ) );
	if( count( $networks ) ) {
		foreach( $networks as $network ) {
			ADAuthInt_Plugin::switch_to_site( $network->id );
			if( current_user_can( 'delete-users' ) ) {
				$asp = maybe_unserialize( get_site_option( 'active_sitewide_plugins' ) );
				if( array_key_exists( ADAUTHINT_PLUGIN_BASENAME, $asp ) ) {
					unset( $asp[ADAUTHINT_PLUGIN_BASENAME] );
					/*$asp = array_splice( $asp, array_search( $asp[ADAUTHINT_PLUGIN_BASENAME], $asp ), 1 );*/
					update_site_option( 'active_sitewide_plugins', $asp );
					echo '<p>' . __( 'The AD Authentication Integration plug-in was successfully deactivated for the network with an ID of ', ADAUTHINT_TEXT_DOMAIN ) . $network->id . '</p>';
				} else {
					echo '<p>';
					printf( __( 'The AD Authentication Integration plug-in was not network-active on the network with an ID of %d, therefore, no changes were made.', ADAUTHINT_TEXT_DOMAIN ), $network->id );
					echo '</p>';
				}
			} else {
				echo '<p>' . __( 'You do not have the appropriate permissions to network deactivate this plug-in on the network with an ID of ', ADAUTHINT_TEXT_DOMAIN ) . $network->id . '</p>';
			}
			ADAuthInt_Plugin::restore_current_site();
		}
		echo '</div>';
	} else {
		echo '<p>' . __( 'Multiple networks could not be found, therefore, no additional changes were made.', ADAUTHINT_TEXT_DOMAIN ) . '</p>';
		echo '</div>';
	}
}